Index: include/AdblockPlus/IFileSystem.h |
diff --git a/include/AdblockPlus/IFileSystem.h b/include/AdblockPlus/IFileSystem.h |
index 54b56be0cd5a0c53ec4a20a67d15f08a54f4e9f4..619b27139b6b1b744c2aaa2b11b44453d03f90e6 100644 |
--- a/include/AdblockPlus/IFileSystem.h |
+++ b/include/AdblockPlus/IFileSystem.h |
@@ -125,9 +125,9 @@ namespace AdblockPlus |
}; |
/** |
* Shared smart pointer to a `IFileSystem` instance. |
*/ |
- typedef std::shared_ptr<IFileSystem> FileSystemPtr; |
+ typedef std::unique_ptr<IFileSystem> FileSystemPtr; |
} |
#endif |
@@ -125,9 +125,9 @@ namespace AdblockPlus |
}; |
/** |
- * Shared smart pointer to a `IFileSystem` instance. |
+ * Unique smart pointer to to a `IFileSystem` instance. |
*/ |